@@ -105,8 +105,9 @@ by B<DENY_FILENAMES> be imposed.
 Example:
 
         DENY_FILENAMES_PER_PATH(
-            qr:/src/: => [qr/[^\w.-]/ => 'source files must be strict'],
-            qr:/doc/: => qr/[^\w\s.-]/i, # document files allow spaces too.
+            qr:/src/:   => [qr/[^\w.-]/ => 'source files must be strict'],
+            qr:/doc/:   => qr/[^\w\s.-]/i, # document files allow spaces too.
+            qr:/notes/: => qr/^$/,         # notes directory allows anything.
         );
 
 =cut
@@ -140,10 +141,9 @@ sub pre_commit {
     foreach my $added ($svnlook->added()) {
 	foreach my $rule (@Per_path_checks) {
 	    if ($added =~ $rule->[0]) {
-		if ($added =~ $rule->[1][0]) {
-		    $errors .= "$HOOK: $rule->[1][1]: $added\n";
-		    next ADDED;
-		}
+		$errors .= "$HOOK: $rule->[1][1]: $added\n"
+		    if $added =~ $rule->[1][0];
+		next ADDED;
 	    }
 	}
 	foreach my $check (@Checks) {
