@@ -7,7 +7,6 @@ use File::Temp qw/tempdir/;
 use File::Spec::Functions;
 use File::Path;
 use File::Copy;
-use File::Slurp;
 use URI::file;
 
 # Make sure the svn messages come in English.
@@ -53,6 +52,13 @@ sub do_script {
     system("$script 1>$stdout 2>$stderr");
 }
 
+sub read_file {
+    my ($file) = @_;
+    open my $fd, '<', $file or die "Can't open '$file': $!\n";
+    local $/ = undef;		# slurp mode
+    return <$fd>;
+}
+
 sub work_ok {
     my ($tag, $cmd) = @_;
     my $dir = newdir();
@@ -146,6 +152,17 @@ sub set_conf {
     close $fd;
 }
 
+sub get_author {
+    my ($t) = @_;
+    my $repo = catfile($t, 'repo');
+    open my $cmd, '-|', "svnlook info $repo"
+	or die "Can't exec svn info\n";
+    chomp(my $author = <$cmd>);
+    local $/ = undef; <$cmd>;
+    close $cmd;
+    return $author;
+}
+
 sub reset_repo {
     my $cleanup = exists $ENV{REPO_CLEANUP} ? $ENV{REPO_CLEANUP} : 1;
     $T = tempdir('t.XXXX', DIR => getcwd(), CLEANUP => $cleanup);
